@@ -25,6 +25,7 @@ from time import time
 
 from metricAbstract import MetricAbstract
 from taylorplot import TaylorPlotMurCSS
+from plotter import Plotter
 
 class MsssError(Exception): pass
     
@@ -33,6 +34,43 @@ class MsssError(Exception): pass
 class Msss(MetricAbstract):
     '''
     Class to calculate the MSSS. Call method "analyze" to get results
+    
+    :param output: Path where the results are saved
+    :param output_plots: Path where the plots are saved
+    :param decadals: a list with decadal experiments, i.e. [1960,1960,...,1995]
+    :param variable: CMOR-Name of variable like 'tas' (Near Surface Temperature)
+    :param project1: CMOR-Name of the project like CMIP5 or BASELINE1
+    :param product1: CMOR-Parameter
+    :param institute1: CMOR-Name of the institute like MPI-M
+    :param model1: CMOR-Name of the used model like MPI-ESM-LR
+    :param experiment1: Experiment name like decadal or historical
+    :param ensemblemembers1: Comma separated string of esemble members like 'r1i1p1,r2i1p1,...'
+    :param project2: CMOR-Name of the project like CMIP5 or BASELINE1
+    :param product2: CMOR-Parameter
+    :param institute2: CMOR-Name of the institute like MPI-M
+    :param model2: CMOR-Name of the used model like MPI-ESM-LR
+    :param experiment2: Experiment name like decs4e or historical
+    :param ensemblemembers2: Comma separated string of esemble members like 'r1i1p1,r2i1p1,...'
+    :param leadtimes: Leadtimes to analyze, ie. 1,2-9
+    :param observation: Observation or Reanalysis Experiment, HadCrut or ERA-Int
+    :param observation_ensemble: If your observation has multiple ensemble members. Not necesary if you use an observation file    
+    :param maskMissingValues: Boolean
+    :param result_grid: Griddescription of resultgrid like r72x36
+    :param cache: Path for cachedir during analysis
+    :param baseDir: Path of Class to find default files
+    :param timeFreq: Timefrequency of the files, ie 'mon' or 'day'
+    :param basic_output: Boolean - If true only basic out is produced (Correlation, MSESS, and Conditional Bias). 
+    :param bootstrap:
+    :param bootstrap2:
+    :param obsRemapped:
+    :param level: For 3D-Files --> Select a single level
+    :param lonlatbox: If you want to select a specific lonlat-Box
+    :param fieldmean: Boolean - If you want to calculate field means
+    :param zonalmean: Boolean - If you want to calculate zonal means
+    :param colormap: Matplotlib Colormap used for ploting
+    :param observation_type: NOT USED ANYMORE!!!
+    :param reanpath: NOT USED ANYMORE!!!
+    :param months: Usefull if your analysing monthly and your experiment name has a month included
     '''
     #Here the output filenames and folder structure get defined
     outputFolderStruct = 'TIME_variable_project1_product1_institute1_model1_experiment1_project2_product2_institute2_model2_experiment2_obsExp_LEVEL_SELLONLAT_YEARRANGE'.split('_')
@@ -71,6 +109,7 @@ class Msss(MetricAbstract):
                      baseDir = '..', 
                      timeFreq = 'mon',
 
+		             basic_output = True,#False,
                      #for bootstrapping
                      bootstrap=None, 
                      bootstrap2=None, 
@@ -79,7 +118,8 @@ class Msss(MetricAbstract):
                      leadtimes_mode = 'yearly',
                      level=None, 
                      lonlatbox=None, 
-                     fieldmean=False, #not finally implemented
+                     fieldmean=False,
+                     zonalmean=False,
                      
                      colormap='RedBlu', #not used
                      observation_type = 'REANALYSIS', #not used ???
@@ -88,50 +128,17 @@ class Msss(MetricAbstract):
                  ):
         '''
         Constructor. Set parameters and calls parent constructor (metricAbstract)
-        
-        :param output: Path where the results are saved
-        :param output_plots: Path where the plots are saved
-        :param decadals: a list with decadal experiments, i.e. [1960,1960,...,1995]
-        :param variable: CMOR-Name of variable like 'tas' (Near Surface Temperature)
-        :param project1: CMOR-Name of the project like CMIP5 or BASELINE1
-        :param product1: CMOR-Parameter
-        :param institute1: CMOR-Name of the institute like MPI-M
-        :param model1: CMOR-Name of the used model like MPI-ESM-LR
-        :param experiment1: Experiment name like decs4e or historical
-        :param project2: CMOR-Name of the project like CMIP5 or BASELINE1
-        :param product2: CMOR-Parameter
-        :param institute2:CMOR-Name of the institute like MPI-M
-        :param model2: CMOR-Name of the used model like MPI-ESM-LR
-        :param experiment2: Experiment name like decs4e or historical
-        :param ensemblemembers: Comma separated string of esemble members like 'r1i1p1,r2i1p1,...'
-        :param leadtimes: Leadtimes to analyze, ie. 1,2-9
-        :param observation: Observation or Reanalysis Experiment, HadCrut or ERA-Int
-        :param maskMissingValues: Boolean 
-        :param result_grid: Griddescription of resultgrid like r72x36
-        :param cache: Path for cachedir during analysis
-        :param baseDir: Path of Class to find default files
-        :param timeFreq: Timefrequency of the files, ie 'mon' or 'day'
-        :param bootstrap:
-        :param bootstrap2:
-        :param obsRemapped:
-        :param level: For 3D-Files --> Select a single level
-        :param lonlatbox: If you want to select a specific lonlat-Box
-        :param fieldmean: Boolean - If you want to calculate global mean
-        :param colormap: Matplotlib Colormap used for ploting
-        :param observation_type: NOT USED ANYMORE!!!
-        :param reanpath: NOT USED ANYMORE!!!
         '''            
         #Add kwargs to attributes
         listOfAttributes = ['decadals','variable',
                             'project1','product1','institute1','model1','experiment2',
                             'project2','product2','institute2','model2','experiment1',
-                            'leadtimes','maskMissingValues','level','lonlatbox','fieldmean',
+                            'leadtimes','maskMissingValues','level','lonlatbox','fieldmean','zonalmean',
                             'bootstrap','bootstrap2','obsRemapped', 'observation_ensemble',
-                            'observation_type','colormap','timeFreq']
+                            'observation_type','colormap','timeFreq','basic_output']
         for attr in listOfAttributes:
             setattr(self, attr, locals()[attr])
                
-        
         if ensemblemembers1 != None and ensemblemembers1 != '*':
             self.ensemblemembers1 = ensemblemembers1.split(',')
         else:
@@ -154,23 +161,28 @@ class Msss(MetricAbstract):
         
             print 'Searching Files' 
             countYears = len(self.decadals)
-            poolArgs = self.getPoolArgs(countYears, self.findFiles, list(self.decadals), self.project2, self.model2, self.variable,
-                                        'mon', self.product2, self.ensemblemembers2, self.institute2, self.experiment2,
-                                        self.maxLeadtime, self.minLeadtime, 'getFiles')
-            self.input2Dict = self.listToYeardict(self.multiProcess(poolArgs)) 
+            
             #print self.input2Dict
             poolArgs = self.getPoolArgs(countYears, self.findFiles, list(self.decadals), self.project1,self.model1,self.variable,
                                         'mon',self.product1,self.ensemblemembers1,self.institute1,self.experiment1,
                                         self.maxLeadtime, self.minLeadtime,'getFiles')
             self.input1Dict = self.listToYeardict(self.multiProcess(poolArgs))
+            poolArgs = self.getPoolArgs(countYears, self.findFiles, list(self.decadals), self.project2, self.model2, self.variable,
+                                        'mon', self.product2, self.ensemblemembers2, self.institute2, self.experiment2,
+                                        self.maxLeadtime, self.minLeadtime, 'getFiles')
+            self.input2Dict = self.listToYeardict(self.multiProcess(poolArgs)) 
             for year in self.decadals:
                 self.observationDict[year] = self.findFiles.getReanalysis(year, self.observation_type, self.obsExp, self.variable, maxLeadtime=self.maxLeadtime, observation_ensemble=self.observation_ensemble, minLeadtime=self.minLeadtime)     
             #print self.observationDict
             print 'Remapping Files'
+            obslist_tmp = list()
             for year in self.decadals:
                 self.input1Remapped[year] = self._remapFiles(self.input1Dict[year], flag=self.product1)
                 self.input2Remapped[year] = self._remapFiles(self.input2Dict[year], flag=self.product2)
-                self.observationRemapped[year] = self.remapFile(self.observationDict[year])
+                #self.observationRemapped[year] = self.remapFile(self.observationDict[year])
+                obslist_tmp.append(self.observationDict[year])
+            self.observationRemapped = self.listToYeardict(self._remapFiles(obslist_tmp))
+            
             self.ensList = self.input1Dict
             self.histList = self.input2Dict   
         else:
@@ -183,6 +195,57 @@ class Msss(MetricAbstract):
                 else:
                     self.observationRemapped[year] = self.obsRemapped[year]
 
+        #select lon/lat box
+        if self.lonlatbox is not None:
+            print 'Selecting lon-lat-box %s' %(self.lonlatbox)
+            for year in self.decadals:
+                self.input1Remapped[year] = self.sellonlatbox(self.input1Remapped[year])
+                self.input2Remapped[year] = self.sellonlatbox(self.input2Remapped[year])
+                self.observationRemapped[year] = self._sellonlatbox(self.observationRemapped[year])         
+
+        #self.fieldmean = True
+        if self.fieldmean:
+            print 'Calculating field mean'
+            #Calculate missing value fields 
+            self.obsmissmask = self.getMissingMaskForFieldMean()     
+            for year in self.decadals:
+                #Apply Missing value Mask to all fields                                          output=self.observationRemapped[year]+'_masked' )
+                self.observationRemapped[year] = self._applyMissingMaskForFieldMean(self.observationRemapped[year], self.obsmissmask)
+                self.input1Remapped[year] = self.applyMissingMaskForFieldMean(self.input1Remapped[year], self.obsmissmask)
+                self.input2Remapped[year] = self.applyMissingMaskForFieldMean(self.input2Remapped[year], self.obsmissmask)
+
+                self.input1Remapped[year] = self.fieldMean(self.input1Remapped[year])
+                self.input2Remapped[year] = self.fieldMean(self.input2Remapped[year])
+                self.observationRemapped[year] = self._fieldMean(self.observationRemapped[year]) 
+
+        #self.zonalmean = True
+        if self.zonalmean:
+            print 'Calculating zonal mean'
+            level_intersection = self.getLevelIntersection(self.observationRemapped[self.decadals[0]], self.input1Remapped[self.decadals[0]][0], self.input2Remapped[self.decadals[0]][0])
+            print 'Common levels: %s' % (','.join(level_intersection))
+            for year in self.decadals:
+                self.observationRemapped[year] = cdo.zonmean(input=self.observationRemapped[year], output=self.observationRemapped[year]+'_zonmean')
+                self.observationRemapped[year] = cdo.sellevel(','.join(level_intersection), input=self.observationRemapped[year], output=self.observationRemapped[year]+'sellevel')
+
+                self.input1Remapped[year] = self.multiProcessCdo(self.input1Remapped[year], 'zonmean')
+                self.input1Remapped[year] = self.multiProcessCdo(self.input1Remapped[year], 'sellevel', ','.join(level_intersection))
+                
+                self.input2Remapped[year] = self.multiProcessCdo(self.input2Remapped[year], 'zonmean')
+                self.input2Remapped[year] = self.multiProcessCdo(self.input2Remapped[year], 'sellevel', ','.join(level_intersection))
+                
+#                tmpList = list()
+#                for fn in self.input1Remapped[year]:
+#                    tmp_file = fn#cdo.zonmean(input=fn,output=fn+'_zonmean')
+#                    tmpList.append(cdo.sellevel(','.join(level_intersection), input=tmp_file, output=tmp_file+'sellevel'))
+#                self.input1Remapped[year] = tmpList
+#                tmpList = list()
+#                for fn in self.input2Remapped[year]:
+#                    tmp_file = fn#cdo.zonmean(input=fn,output=fn+'_zonmean')
+#                    tmpList.append(cdo.sellevel(','.join(level_intersection), input=tmp_file, output=tmp_file+'sellevel'))
+#                self.input2Remapped[year] = tmpList
+                    
+                    
+
     def analyze(self):
         '''
         Main method to calculate the MSSS. Following steps are performed:
@@ -202,22 +265,6 @@ class Msss(MetricAbstract):
             self.observationRemapped
         except AttributeError:
             raise MsssError, 'Please run "prepareInput() first or provide input data'
-            
-        #select lon/lat box
-        if self.lonlatbox is not None:
-            print 'Selecting lon-lat-box %s' %(self.lonlatbox)
-            for year in self.decadals:
-                self.input1Remapped[year] = self.sellonlatbox(self.input1Remapped[year])
-                self.input2Remapped[year] = self.sellonlatbox(self.input2Remapped[year])
-                self.observationRemapped[year] = self._sellonlatbox(self.observationRemapped[year])         
-
-        if self.fieldmean:
-            print 'Calculating field mean'
-            for year in self.decadals:
-                self.input1Remapped[year] = self.fieldMean(self.input1Remapped[year])
-                self.input2Remapped[year] = self.fieldMean(self.input2Remapped[year])
-                self.observationRemapped[year] = self._fieldMean(self.observationRemapped[year]) 
-            
 
         if self.bootstrap is None:
             print 'Calculating ensemble mean'
@@ -241,8 +288,12 @@ class Msss(MetricAbstract):
         input2Anomalies = self.getAnomalies(input2Ensemblemean, input2CrossvalMean)
         self.constantField = self.createConstantFile(self.gridFile)
         
-        self.misvalMask = self.calcMissingValueMask(self.observationRemappedAnom)
-        
+        if self.maskMissingValues:
+            if not self.fieldmean:
+                self.misvalMask = self.calcMissingValueMask(self.observationRemappedAnom)
+            else:
+                self.misvalMask = self.constantField
+            
         rangeCount = len(self.getYearRange())
         firstYearList = list()
         lastYearList = list()
@@ -260,8 +311,41 @@ class Msss(MetricAbstract):
         
         if self.fieldmean:
             #construct a taylor plot
-            taylor = TaylorPlotMurCSS(negativeCorr=True)
-            taylor.constructPlot(resultList, self.outputPlots)
+            outputPlots = self.outputPlots+'accuracy/'
+            self.makeFolder(outputPlots)
+            #taylor = TaylorPlotMurCSS(negativeCorr=False)
+            #taylor.constructPlot(resultList, outputPlots)
+            flag1 = self.constructName(self.fileNameFlag, exp='1', startYear='1', endYear='1')
+            flag1 = flag1[4:]
+            flag2 = self.constructName(self.fileNameFlag, exp='2', startYear='1', endYear='1')
+            flag2= flag2[4:]
+            fnFlagVs = self.constructName(self.fileNameFlagVs, exp='', startYear='1', endYear='1')
+            fnFlagVs = fnFlagVs[4:]
+            plot_list = [('correlation','Anomaly Correlation',[0,1]),('msss','Mean Squared Error Skill Score',[-1,1])]
+            Plotter.plotLeadtimeseries(resultList,[flag1,flag2,fnFlagVs],plot_list)
+            Plotter.saveFig(outputPlots, 'accuracy_leadtimeseries_all')
+            
+            plot_list = [('correlation','Anomaly Correlation',[0,1]),('msss','Mean Squared Error Skill Score',[-1,1])]
+            Plotter.plotLeadtimeseries(resultList,[flag1],plot_list)
+            Plotter.saveFig(outputPlots, flag1+'accuracy_leadtimeseries_input1')
+            
+            plot_list = [('correlation','Anomaly Correlation',[0,1]),('msss','Mean Squared Error Skill Score',[-1,1])]
+            Plotter.plotLeadtimeseries(resultList,[flag2],plot_list)
+            Plotter.saveFig(outputPlots, flag2+'accuracy_leadtimeseries_input1')
+            
+            plot_list = [('correlation','Anomaly Correlation',[0,1]),('msss','Mean Squared Error Skill Score',[-1,1])]
+            Plotter.plotLeadtimeseries(resultList,[fnFlagVs],plot_list)
+            Plotter.saveFig(outputPlots, fnFlagVs+'accuracy_leadtimeseries_versus')
+        
+        elif self.zonalmean:
+            fileList = list()
+            for rList in resultList:  
+                fileList = fileList + rList          
+            filesToPlot = len(fileList)
+            for fn in fileList:
+                Plotter.plotVerticalProfile(fn,-1,1)
+                #Plotter.saveFig(output_folder, fn)
+                Plotter.saveFig(self.outputPlots, fn.split(self.outputDir)[-1])
         else:
             #plot fields
             if self.bootstrap is None:
@@ -279,12 +363,13 @@ class Msss(MetricAbstract):
 #                min[corr_ind] = -0.6
 #                max[corr_ind] = 0.6
                 poolArgs = self.getPoolArgs(filesToPlot,self,fileList,list(min),list(max),'_plotField')
-                #resultList = self.multiProcess(poolArgs)
+                resultList = self.multiProcess(poolArgs)
                 
-                for i,f in enumerate(fileList):     
-                    if not 'biasslope' in f:
-                        if not 'std_ratio' in f:
-                            self._plotField(f, min[i], max[i])
+                #Plotting without multiprocessing
+#                for i,f in enumerate(fileList):     
+#                    if not 'biasslope' in f:
+#                        if not 'std_ratio' in f:
+#                            self._plotField(f, min[i], max[i])
                   
         
            
@@ -306,7 +391,10 @@ class Msss(MetricAbstract):
         :param endYear: 
         
         '''
-        print 'Analyzing year %s to %s' %(startYear, endYear)
+        if startYear == endYear:
+            print 'Analyzing leadtime %s' %(startYear)
+        else:
+            print 'Analyzing leadtime %s to %s' %(startYear, endYear)
 
         base = '%s-%s'%(startYear, endYear)
         #get file names
@@ -318,13 +406,13 @@ class Msss(MetricAbstract):
 
         #make outputfolders
         if self.bootstrap is None:
-            model1Output = self.makeFolder(self.outputDir+base+'/'+flag1+'/msss')
-            model2Output = self.makeFolder(self.outputDir+base+'/'+flag2+'/msss')
-            vsOutput = self.makeFolder(self.outputDir+base+'/%s_vs_%s/msss'%(flag1,flag2))
+            model1Output = self.makeFolder(self.outputDir+base+'/'+flag1+'/accuracy')
+            model2Output = self.makeFolder(self.outputDir+base+'/'+flag2+'/accuracy')
+            vsOutput = self.makeFolder(self.outputDir+base+'/%s_vs_%s/accuracy'%(flag1,flag2))
             #make plot folders
-            model1Plot = self.makeFolder(self.outputPlots+base+'/'+flag1+'/msss')
-            model2Plot = self.makeFolder(self.outputPlots+base+'/'+flag2+'/msss')
-            vsPlot = self.makeFolder(self.outputPlots+base+'/%s_vs_%s/msss'%(flag1,flag2))
+            model1Plot = self.makeFolder(self.outputPlots+base+'/'+flag1+'/accuracy')
+            model2Plot = self.makeFolder(self.outputPlots+base+'/'+flag2+'/accuracy')
+            vsPlot = self.makeFolder(self.outputPlots+base+'/%s_vs_%s/accuracy'%(flag1,flag2))
         else:
             model1Output = self.outputDir
             model2Output = self.outputDir
@@ -344,10 +432,10 @@ class Msss(MetricAbstract):
         correlationHist = self.getCorrelationAndVariancesAndMSSS(histSelYearTimmean,obsSelYearTimmean, fnFlag2, model2Output)
         
         msssInitVsUninit = self.getInitVsUninit(correlation, correlationHist, fnFlagVs, vsOutput)
-        
-        rmss = self.getRMSS(correlation['msss'], fnFlag1, model1Output)
-        rmssHist = self.getRMSS(correlationHist['msss'], fnFlag2, model2Output)
-        rmssInitvsUninit = self.getRMSS(msssInitVsUninit, fnFlagVs, vsOutput)  
+        if not self.basic_output: 
+            rmss = self.getRMSS(correlation['msss'], fnFlag1, model1Output)
+            rmssHist = self.getRMSS(correlationHist['msss'], fnFlag2, model2Output)
+            rmssInitvsUninit = self.getRMSS(msssInitVsUninit, fnFlagVs, vsOutput)  
         
         return self.applyMissingValueMask(startYear, endYear, [model1Output,model2Output,vsOutput])
 
@@ -375,22 +463,24 @@ class Msss(MetricAbstract):
         msss = cdo.div(input='-sub ' + initResults['msss'] + ' ' + uninitResults['msss'] + 
                              ' -sub ' + constantField + ' ' + uninitResults['msss'], 
                        output=outputDir+flag+'_msss.nc')
-        
-        #conditional bias slope 
-        slopeBiasInit = cdo.abs(input=initResults['biasSlopeMinusOne'], 
+        if self.basic_output:
+	    return msss
+	else:
+            #conditional bias slope 
+            slopeBiasInit = cdo.abs(input=initResults['biasSlopeMinusOne'], 
                                                      output=self.tmpDir+self.extractFilename(initResults['biasSlopeMinusOne'])+'_abs')
-        slopeBiasUninit = cdo.abs(input=uninitResults['biasSlopeMinusOne'], 
+            slopeBiasUninit = cdo.abs(input=uninitResults['biasSlopeMinusOne'], 
                                                      output=self.tmpDir+self.extractFilename(uninitResults['biasSlopeMinusOne'])+'_abs')
-        slopeBias = cdo.sub(input=' '.join([slopeBiasInit, slopeBiasUninit]),
+            slopeBias = cdo.sub(input=' '.join([slopeBiasInit, slopeBiasUninit]),
                              output=outputDir+flag+'_biasslope-1.nc')
         
-        #conditional bias skill score
-        biasSKillScore = cdo.sub(input=' '.join([self.constantField,
+            #conditional bias skill score
+            biasSKillScore = cdo.sub(input=' '.join([self.constantField,
                                                  cdo.div(input=' '.join([slopeBiasInit, slopeBiasUninit]), 
                                                          output=self.tmpDir+flag+'_biasskillDIV.nc')]),
                                  output=outputDir+flag+'_biasSkillScore.nc')
         
-        return msss
+            return msss
            
     def getCorrelationAndVariancesAndMSSS(self, hindcast, observation, flag, outputDir):
         '''
@@ -431,27 +521,27 @@ class Msss(MetricAbstract):
         varianceObservation = cdo.timstd(input=mergeObservations, output=observation[self.decadals[0]]+flag+'_variance')
         corr = cdo.timcor(input=' '.join([mergeHindcast, mergeObservations]), output=outputDir+flag+'_correlation.nc')
         
-        #standard deviation ratio
-        stdRatio = cdo.div(input=' '.join([varianceObservation, varianceHindcast]), 
+        bias = cdo.sub(input=corr+' '+ '-div ' + varianceHindcast + ' ' + varianceObservation,    
+                       output=outputDir+flag+'_conditional_bias.nc')
+        msss = cdo.sub(input='-sqr ' + corr + ' -sqr ' + bias,
+                       output=outputDir+flag+'_msss.nc')
+
+        if self.basic_output:
+	    return dict(msss= msss, bias= bias, corr= corr)
+	else:
+	    #standard deviation ratio
+            stdRatio = cdo.div(input=' '.join([varianceObservation, varianceHindcast]), 
                            output=outputDir+flag+'_std_ratio.nc')
         
-        #slope of conditional bias
-        biasSlope = cdo.mul(input=' '.join([stdRatio, corr]),
+            #slope of conditional bias
+            biasSlope = cdo.mul(input=' '.join([stdRatio, corr]),
                             output=outputDir+flag+'_biasslope.nc')
         
-        #slope -1
-        biasSlopeMinusOne = cdo.sub(input=' '.join([biasSlope, self.constantField]),
+            #slope -1
+            biasSlopeMinusOne = cdo.sub(input=' '.join([biasSlope, self.constantField]),
                                     output=outputDir+flag+'_biasslope-1.nc')
-        bias = cdo.sub(input=corr+' '+ '-div ' + varianceHindcast + ' ' + varianceObservation, 
-                       output=outputDir+flag+'_conditional_bias.nc')
-#        bias = cdo.sub(input=corr+' '+ cdo.div(input=varianceHindcast + ' ' + varianceObservation, output=varianceHindcast+'div'), 
-#                       output=outputDir+flag+'_conditional_bias.nc')
-        msss = cdo.sub(input='-sqr ' + corr + ' -sqr ' + bias, 
-                       output=outputDir+flag+'_msss.nc')
-#        msss = cdo.sub(input=cdo.sqr(input=corr,output=corr+'sqr') + ' ' + cdo.sqr(input=bias,output=bias+'sqr'), 
-#                       output=outputDir+flag+'_msss.nc')
         
-        return dict(msss= msss, bias= bias, corr= corr, biasSlope=biasSlope, stdRatio=stdRatio, biasSlopeMinusOne=biasSlopeMinusOne)
+            return dict(msss= msss, bias= bias, corr= corr, biasSlope=biasSlope, stdRatio=stdRatio, biasSlopeMinusOne=biasSlopeMinusOne)
         
     def getMSE(self, anomalies, obsAnom):
         '''
